// Do NOT change. Changes will be lost next time file is generated

#define R__DICTIONARY_FILENAME G__Unuran
#define R__NO_DEPRECATION

/*******************************************************************/
#include <cstddef>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <cassert>
#define G__DICTIONARY
#include "ROOT/RConfig.hxx"
#include "TClass.h"
#include "TDictAttributeMap.h"
#include "TInterpreter.h"
#include "TROOT.h"
#include "TBuffer.h"
#include "TMemberInspector.h"
#include "TInterpreter.h"
#include "TVirtualMutex.h"
#include "TError.h"

#ifndef G__ROOT
#define G__ROOT
#endif

#include "RtypesImp.h"
#include "TIsAProxy.h"
#include "TFileMergeInfo.h"
#include <algorithm>
#include "TCollectionProxyInfo.h"
/*******************************************************************/

#include "TDataMember.h"

// Header files passed as explicit arguments
#include "TUnuran.h"
#include "TUnuranBaseDist.h"
#include "TUnuranContDist.h"
#include "TUnuranDiscrDist.h"
#include "TUnuranEmpDist.h"
#include "TUnuranMultiContDist.h"
#include "TUnuranSampler.h"

// Header files passed via #pragma extra_include

// The generated code does not explicitly qualify STL entities
namespace std {} using namespace std;

namespace ROOT {
   static void delete_TUnuranBaseDist(void *p);
   static void deleteArray_TUnuranBaseDist(void *p);
   static void destruct_TUnuranBaseDist(void *p);

   // Function generating the singleton type initializer
   static TGenericClassInfo *GenerateInitInstanceLocal(const ::TUnuranBaseDist*)
   {
      ::TUnuranBaseDist *ptr = nullptr;
      static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::TUnuranBaseDist >(nullptr);
      static ::ROOT::TGenericClassInfo 
         instance("TUnuranBaseDist", ::TUnuranBaseDist::Class_Version(), "TUnuranBaseDist.h", 29,
                  typeid(::TUnuranBaseDist), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                  &::TUnuranBaseDist::Dictionary, isa_proxy, 4,
                  sizeof(::TUnuranBaseDist) );
      instance.SetDelete(&delete_TUnuranBaseDist);
      instance.SetDeleteArray(&deleteArray_TUnuranBaseDist);
      instance.SetDestructor(&destruct_TUnuranBaseDist);
      return &instance;
   }
   TGenericClassInfo *GenerateInitInstance(const ::TUnuranBaseDist*)
   {
      return GenerateInitInstanceLocal(static_cast<::TUnuranBaseDist*>(nullptr));
   }
   // Static variable to force the class initialization
   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const ::TUnuranBaseDist*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));
} // end of namespace ROOT

namespace ROOT {
   static TClass *TUnuran_Dictionary();
   static void TUnuran_TClassManip(TClass*);
   static void *new_TUnuran(void *p = nullptr);
   static void *newArray_TUnuran(Long_t size, void *p);
   static void delete_TUnuran(void *p);
   static void deleteArray_TUnuran(void *p);
   static void destruct_TUnuran(void *p);

   // Function generating the singleton type initializer
   static TGenericClassInfo *GenerateInitInstanceLocal(const ::TUnuran*)
   {
      ::TUnuran *ptr = nullptr;
      static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(::TUnuran));
      static ::ROOT::TGenericClassInfo 
         instance("TUnuran", "TUnuran.h", 79,
                  typeid(::TUnuran), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                  &TUnuran_Dictionary, isa_proxy, 4,
                  sizeof(::TUnuran) );
      instance.SetNew(&new_TUnuran);
      instance.SetNewArray(&newArray_TUnuran);
      instance.SetDelete(&delete_TUnuran);
      instance.SetDeleteArray(&deleteArray_TUnuran);
      instance.SetDestructor(&destruct_TUnuran);
      return &instance;
   }
   TGenericClassInfo *GenerateInitInstance(const ::TUnuran*)
   {
      return GenerateInitInstanceLocal(static_cast<::TUnuran*>(nullptr));
   }
   // Static variable to force the class initialization
   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const ::TUnuran*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));

   // Dictionary for non-ClassDef classes
   static TClass *TUnuran_Dictionary() {
      TClass* theClass =::ROOT::GenerateInitInstanceLocal(static_cast<const ::TUnuran*>(nullptr))->GetClass();
      TUnuran_TClassManip(theClass);
   return theClass;
   }

   static void TUnuran_TClassManip(TClass* ){
   }

} // end of namespace ROOT

namespace ROOT {
   static void *new_TUnuranContDist(void *p = nullptr);
   static void *newArray_TUnuranContDist(Long_t size, void *p);
   static void delete_TUnuranContDist(void *p);
   static void deleteArray_TUnuranContDist(void *p);
   static void destruct_TUnuranContDist(void *p);

   // Function generating the singleton type initializer
   static TGenericClassInfo *GenerateInitInstanceLocal(const ::TUnuranContDist*)
   {
      ::TUnuranContDist *ptr = nullptr;
      static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::TUnuranContDist >(nullptr);
      static ::ROOT::TGenericClassInfo 
         instance("TUnuranContDist", ::TUnuranContDist::Class_Version(), "TUnuranContDist.h", 48,
                  typeid(::TUnuranContDist), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                  &::TUnuranContDist::Dictionary, isa_proxy, 4,
                  sizeof(::TUnuranContDist) );
      instance.SetNew(&new_TUnuranContDist);
      instance.SetNewArray(&newArray_TUnuranContDist);
      instance.SetDelete(&delete_TUnuranContDist);
      instance.SetDeleteArray(&deleteArray_TUnuranContDist);
      instance.SetDestructor(&destruct_TUnuranContDist);
      return &instance;
   }
   TGenericClassInfo *GenerateInitInstance(const ::TUnuranContDist*)
   {
      return GenerateInitInstanceLocal(static_cast<::TUnuranContDist*>(nullptr));
   }
   // Static variable to force the class initialization
   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const ::TUnuranContDist*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));
} // end of namespace ROOT

namespace ROOT {
   static void delete_TUnuranDiscrDist(void *p);
   static void deleteArray_TUnuranDiscrDist(void *p);
   static void destruct_TUnuranDiscrDist(void *p);

   // Function generating the singleton type initializer
   static TGenericClassInfo *GenerateInitInstanceLocal(const ::TUnuranDiscrDist*)
   {
      ::TUnuranDiscrDist *ptr = nullptr;
      static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::TUnuranDiscrDist >(nullptr);
      static ::ROOT::TGenericClassInfo 
         instance("TUnuranDiscrDist", ::TUnuranDiscrDist::Class_Version(), "TUnuranDiscrDist.h", 51,
                  typeid(::TUnuranDiscrDist), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                  &::TUnuranDiscrDist::Dictionary, isa_proxy, 4,
                  sizeof(::TUnuranDiscrDist) );
      instance.SetDelete(&delete_TUnuranDiscrDist);
      instance.SetDeleteArray(&deleteArray_TUnuranDiscrDist);
      instance.SetDestructor(&destruct_TUnuranDiscrDist);
      return &instance;
   }
   TGenericClassInfo *GenerateInitInstance(const ::TUnuranDiscrDist*)
   {
      return GenerateInitInstanceLocal(static_cast<::TUnuranDiscrDist*>(nullptr));
   }
   // Static variable to force the class initialization
   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const ::TUnuranDiscrDist*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));
} // end of namespace ROOT

namespace ROOT {
   static void *new_TUnuranEmpDist(void *p = nullptr);
   static void *newArray_TUnuranEmpDist(Long_t size, void *p);
   static void delete_TUnuranEmpDist(void *p);
   static void deleteArray_TUnuranEmpDist(void *p);
   static void destruct_TUnuranEmpDist(void *p);

   // Function generating the singleton type initializer
   static TGenericClassInfo *GenerateInitInstanceLocal(const ::TUnuranEmpDist*)
   {
      ::TUnuranEmpDist *ptr = nullptr;
      static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::TUnuranEmpDist >(nullptr);
      static ::ROOT::TGenericClassInfo 
         instance("TUnuranEmpDist", ::TUnuranEmpDist::Class_Version(), "TUnuranEmpDist.h", 49,
                  typeid(::TUnuranEmpDist), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                  &::TUnuranEmpDist::Dictionary, isa_proxy, 4,
                  sizeof(::TUnuranEmpDist) );
      instance.SetNew(&new_TUnuranEmpDist);
      instance.SetNewArray(&newArray_TUnuranEmpDist);
      instance.SetDelete(&delete_TUnuranEmpDist);
      instance.SetDeleteArray(&deleteArray_TUnuranEmpDist);
      instance.SetDestructor(&destruct_TUnuranEmpDist);
      return &instance;
   }
   TGenericClassInfo *GenerateInitInstance(const ::TUnuranEmpDist*)
   {
      return GenerateInitInstanceLocal(static_cast<::TUnuranEmpDist*>(nullptr));
   }
   // Static variable to force the class initialization
   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const ::TUnuranEmpDist*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));
} // end of namespace ROOT

namespace ROOT {
   static void *new_TUnuranMultiContDist(void *p = nullptr);
   static void *newArray_TUnuranMultiContDist(Long_t size, void *p);
   static void delete_TUnuranMultiContDist(void *p);
   static void deleteArray_TUnuranMultiContDist(void *p);
   static void destruct_TUnuranMultiContDist(void *p);

   // Function generating the singleton type initializer
   static TGenericClassInfo *GenerateInitInstanceLocal(const ::TUnuranMultiContDist*)
   {
      ::TUnuranMultiContDist *ptr = nullptr;
      static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::TUnuranMultiContDist >(nullptr);
      static ::ROOT::TGenericClassInfo 
         instance("TUnuranMultiContDist", ::TUnuranMultiContDist::Class_Version(), "TUnuranMultiContDist.h", 47,
                  typeid(::TUnuranMultiContDist), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                  &::TUnuranMultiContDist::Dictionary, isa_proxy, 4,
                  sizeof(::TUnuranMultiContDist) );
      instance.SetNew(&new_TUnuranMultiContDist);
      instance.SetNewArray(&newArray_TUnuranMultiContDist);
      instance.SetDelete(&delete_TUnuranMultiContDist);
      instance.SetDeleteArray(&deleteArray_TUnuranMultiContDist);
      instance.SetDestructor(&destruct_TUnuranMultiContDist);
      return &instance;
   }
   TGenericClassInfo *GenerateInitInstance(const ::TUnuranMultiContDist*)
   {
      return GenerateInitInstanceLocal(static_cast<::TUnuranMultiContDist*>(nullptr));
   }
   // Static variable to force the class initialization
   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const ::TUnuranMultiContDist*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));
} // end of namespace ROOT

namespace ROOT {
   static void *new_TUnuranSampler(void *p = nullptr);
   static void *newArray_TUnuranSampler(Long_t size, void *p);
   static void delete_TUnuranSampler(void *p);
   static void deleteArray_TUnuranSampler(void *p);
   static void destruct_TUnuranSampler(void *p);

   // Function generating the singleton type initializer
   static TGenericClassInfo *GenerateInitInstanceLocal(const ::TUnuranSampler*)
   {
      ::TUnuranSampler *ptr = nullptr;
      static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::TUnuranSampler >(nullptr);
      static ::ROOT::TGenericClassInfo 
         instance("TUnuranSampler", ::TUnuranSampler::Class_Version(), "TUnuranSampler.h", 51,
                  typeid(::TUnuranSampler), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                  &::TUnuranSampler::Dictionary, isa_proxy, 4,
                  sizeof(::TUnuranSampler) );
      instance.SetNew(&new_TUnuranSampler);
      instance.SetNewArray(&newArray_TUnuranSampler);
      instance.SetDelete(&delete_TUnuranSampler);
      instance.SetDeleteArray(&deleteArray_TUnuranSampler);
      instance.SetDestructor(&destruct_TUnuranSampler);
      return &instance;
   }
   TGenericClassInfo *GenerateInitInstance(const ::TUnuranSampler*)
   {
      return GenerateInitInstanceLocal(static_cast<::TUnuranSampler*>(nullptr));
   }
   // Static variable to force the class initialization
   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const ::TUnuranSampler*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));
} // end of namespace ROOT

//______________________________________________________________________________
atomic_TClass_ptr TUnuranBaseDist::fgIsA(nullptr);  // static to hold class pointer

//______________________________________________________________________________
const char *TUnuranBaseDist::Class_Name()
{
   return "TUnuranBaseDist";
}

//______________________________________________________________________________
const char *TUnuranBaseDist::ImplFileName()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TUnuranBaseDist*)nullptr)->GetImplFileName();
}

//______________________________________________________________________________
int TUnuranBaseDist::ImplFileLine()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TUnuranBaseDist*)nullptr)->GetImplFileLine();
}

//______________________________________________________________________________
TClass *TUnuranBaseDist::Dictionary()
{
   fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TUnuranBaseDist*)nullptr)->GetClass();
   return fgIsA;
}

//______________________________________________________________________________
TClass *TUnuranBaseDist::Class()
{
   if (!fgIsA.load()) { R__LOCKGUARD(gInterpreterMutex); fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TUnuranBaseDist*)nullptr)->GetClass(); }
   return fgIsA;
}

//______________________________________________________________________________
atomic_TClass_ptr TUnuranContDist::fgIsA(nullptr);  // static to hold class pointer

//______________________________________________________________________________
const char *TUnuranContDist::Class_Name()
{
   return "TUnuranContDist";
}

//______________________________________________________________________________
const char *TUnuranContDist::ImplFileName()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TUnuranContDist*)nullptr)->GetImplFileName();
}

//______________________________________________________________________________
int TUnuranContDist::ImplFileLine()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TUnuranContDist*)nullptr)->GetImplFileLine();
}

//______________________________________________________________________________
TClass *TUnuranContDist::Dictionary()
{
   fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TUnuranContDist*)nullptr)->GetClass();
   return fgIsA;
}

//______________________________________________________________________________
TClass *TUnuranContDist::Class()
{
   if (!fgIsA.load()) { R__LOCKGUARD(gInterpreterMutex); fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TUnuranContDist*)nullptr)->GetClass(); }
   return fgIsA;
}

//______________________________________________________________________________
atomic_TClass_ptr TUnuranDiscrDist::fgIsA(nullptr);  // static to hold class pointer

//______________________________________________________________________________
const char *TUnuranDiscrDist::Class_Name()
{
   return "TUnuranDiscrDist";
}

//______________________________________________________________________________
const char *TUnuranDiscrDist::ImplFileName()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TUnuranDiscrDist*)nullptr)->GetImplFileName();
}

//______________________________________________________________________________
int TUnuranDiscrDist::ImplFileLine()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TUnuranDiscrDist*)nullptr)->GetImplFileLine();
}

//______________________________________________________________________________
TClass *TUnuranDiscrDist::Dictionary()
{
   fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TUnuranDiscrDist*)nullptr)->GetClass();
   return fgIsA;
}

//______________________________________________________________________________
TClass *TUnuranDiscrDist::Class()
{
   if (!fgIsA.load()) { R__LOCKGUARD(gInterpreterMutex); fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TUnuranDiscrDist*)nullptr)->GetClass(); }
   return fgIsA;
}

//______________________________________________________________________________
atomic_TClass_ptr TUnuranEmpDist::fgIsA(nullptr);  // static to hold class pointer

//______________________________________________________________________________
const char *TUnuranEmpDist::Class_Name()
{
   return "TUnuranEmpDist";
}

//______________________________________________________________________________
const char *TUnuranEmpDist::ImplFileName()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TUnuranEmpDist*)nullptr)->GetImplFileName();
}

//______________________________________________________________________________
int TUnuranEmpDist::ImplFileLine()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TUnuranEmpDist*)nullptr)->GetImplFileLine();
}

//______________________________________________________________________________
TClass *TUnuranEmpDist::Dictionary()
{
   fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TUnuranEmpDist*)nullptr)->GetClass();
   return fgIsA;
}

//______________________________________________________________________________
TClass *TUnuranEmpDist::Class()
{
   if (!fgIsA.load()) { R__LOCKGUARD(gInterpreterMutex); fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TUnuranEmpDist*)nullptr)->GetClass(); }
   return fgIsA;
}

//______________________________________________________________________________
atomic_TClass_ptr TUnuranMultiContDist::fgIsA(nullptr);  // static to hold class pointer

//______________________________________________________________________________
const char *TUnuranMultiContDist::Class_Name()
{
   return "TUnuranMultiContDist";
}

//______________________________________________________________________________
const char *TUnuranMultiContDist::ImplFileName()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TUnuranMultiContDist*)nullptr)->GetImplFileName();
}

//______________________________________________________________________________
int TUnuranMultiContDist::ImplFileLine()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TUnuranMultiContDist*)nullptr)->GetImplFileLine();
}

//______________________________________________________________________________
TClass *TUnuranMultiContDist::Dictionary()
{
   fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TUnuranMultiContDist*)nullptr)->GetClass();
   return fgIsA;
}

//______________________________________________________________________________
TClass *TUnuranMultiContDist::Class()
{
   if (!fgIsA.load()) { R__LOCKGUARD(gInterpreterMutex); fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TUnuranMultiContDist*)nullptr)->GetClass(); }
   return fgIsA;
}

//______________________________________________________________________________
atomic_TClass_ptr TUnuranSampler::fgIsA(nullptr);  // static to hold class pointer

//______________________________________________________________________________
const char *TUnuranSampler::Class_Name()
{
   return "TUnuranSampler";
}

//______________________________________________________________________________
const char *TUnuranSampler::ImplFileName()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TUnuranSampler*)nullptr)->GetImplFileName();
}

//______________________________________________________________________________
int TUnuranSampler::ImplFileLine()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TUnuranSampler*)nullptr)->GetImplFileLine();
}

//______________________________________________________________________________
TClass *TUnuranSampler::Dictionary()
{
   fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TUnuranSampler*)nullptr)->GetClass();
   return fgIsA;
}

//______________________________________________________________________________
TClass *TUnuranSampler::Class()
{
   if (!fgIsA.load()) { R__LOCKGUARD(gInterpreterMutex); fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TUnuranSampler*)nullptr)->GetClass(); }
   return fgIsA;
}

//______________________________________________________________________________
void TUnuranBaseDist::Streamer(TBuffer &R__b)
{
   // Stream an object of class TUnuranBaseDist.

   if (R__b.IsReading()) {
      R__b.ReadClassBuffer(TUnuranBaseDist::Class(),this);
   } else {
      R__b.WriteClassBuffer(TUnuranBaseDist::Class(),this);
   }
}

namespace ROOT {
   // Wrapper around operator delete
   static void delete_TUnuranBaseDist(void *p) {
      delete (static_cast<::TUnuranBaseDist*>(p));
   }
   static void deleteArray_TUnuranBaseDist(void *p) {
      delete [] (static_cast<::TUnuranBaseDist*>(p));
   }
   static void destruct_TUnuranBaseDist(void *p) {
      typedef ::TUnuranBaseDist current_t;
      (static_cast<current_t*>(p))->~current_t();
   }
} // end of namespace ROOT for class ::TUnuranBaseDist

namespace ROOT {
   // Wrappers around operator new
   static void *new_TUnuran(void *p) {
      return  p ? new(p) ::TUnuran : new ::TUnuran;
   }
   static void *newArray_TUnuran(Long_t nElements, void *p) {
      return p ? new(p) ::TUnuran[nElements] : new ::TUnuran[nElements];
   }
   // Wrapper around operator delete
   static void delete_TUnuran(void *p) {
      delete (static_cast<::TUnuran*>(p));
   }
   static void deleteArray_TUnuran(void *p) {
      delete [] (static_cast<::TUnuran*>(p));
   }
   static void destruct_TUnuran(void *p) {
      typedef ::TUnuran current_t;
      (static_cast<current_t*>(p))->~current_t();
   }
} // end of namespace ROOT for class ::TUnuran

//______________________________________________________________________________
void TUnuranContDist::Streamer(TBuffer &R__b)
{
   // Stream an object of class TUnuranContDist.

   if (R__b.IsReading()) {
      R__b.ReadClassBuffer(TUnuranContDist::Class(),this);
   } else {
      R__b.WriteClassBuffer(TUnuranContDist::Class(),this);
   }
}

namespace ROOT {
   // Wrappers around operator new
   static void *new_TUnuranContDist(void *p) {
      return  p ? new(p) ::TUnuranContDist : new ::TUnuranContDist;
   }
   static void *newArray_TUnuranContDist(Long_t nElements, void *p) {
      return p ? new(p) ::TUnuranContDist[nElements] : new ::TUnuranContDist[nElements];
   }
   // Wrapper around operator delete
   static void delete_TUnuranContDist(void *p) {
      delete (static_cast<::TUnuranContDist*>(p));
   }
   static void deleteArray_TUnuranContDist(void *p) {
      delete [] (static_cast<::TUnuranContDist*>(p));
   }
   static void destruct_TUnuranContDist(void *p) {
      typedef ::TUnuranContDist current_t;
      (static_cast<current_t*>(p))->~current_t();
   }
} // end of namespace ROOT for class ::TUnuranContDist

//______________________________________________________________________________
void TUnuranDiscrDist::Streamer(TBuffer &R__b)
{
   // Stream an object of class TUnuranDiscrDist.

   if (R__b.IsReading()) {
      R__b.ReadClassBuffer(TUnuranDiscrDist::Class(),this);
   } else {
      R__b.WriteClassBuffer(TUnuranDiscrDist::Class(),this);
   }
}

namespace ROOT {
   // Wrapper around operator delete
   static void delete_TUnuranDiscrDist(void *p) {
      delete (static_cast<::TUnuranDiscrDist*>(p));
   }
   static void deleteArray_TUnuranDiscrDist(void *p) {
      delete [] (static_cast<::TUnuranDiscrDist*>(p));
   }
   static void destruct_TUnuranDiscrDist(void *p) {
      typedef ::TUnuranDiscrDist current_t;
      (static_cast<current_t*>(p))->~current_t();
   }
} // end of namespace ROOT for class ::TUnuranDiscrDist

//______________________________________________________________________________
void TUnuranEmpDist::Streamer(TBuffer &R__b)
{
   // Stream an object of class TUnuranEmpDist.

   if (R__b.IsReading()) {
      R__b.ReadClassBuffer(TUnuranEmpDist::Class(),this);
   } else {
      R__b.WriteClassBuffer(TUnuranEmpDist::Class(),this);
   }
}

namespace ROOT {
   // Wrappers around operator new
   static void *new_TUnuranEmpDist(void *p) {
      return  p ? new(p) ::TUnuranEmpDist : new ::TUnuranEmpDist;
   }
   static void *newArray_TUnuranEmpDist(Long_t nElements, void *p) {
      return p ? new(p) ::TUnuranEmpDist[nElements] : new ::TUnuranEmpDist[nElements];
   }
   // Wrapper around operator delete
   static void delete_TUnuranEmpDist(void *p) {
      delete (static_cast<::TUnuranEmpDist*>(p));
   }
   static void deleteArray_TUnuranEmpDist(void *p) {
      delete [] (static_cast<::TUnuranEmpDist*>(p));
   }
   static void destruct_TUnuranEmpDist(void *p) {
      typedef ::TUnuranEmpDist current_t;
      (static_cast<current_t*>(p))->~current_t();
   }
} // end of namespace ROOT for class ::TUnuranEmpDist

//______________________________________________________________________________
void TUnuranMultiContDist::Streamer(TBuffer &R__b)
{
   // Stream an object of class TUnuranMultiContDist.

   if (R__b.IsReading()) {
      R__b.ReadClassBuffer(TUnuranMultiContDist::Class(),this);
   } else {
      R__b.WriteClassBuffer(TUnuranMultiContDist::Class(),this);
   }
}

namespace ROOT {
   // Wrappers around operator new
   static void *new_TUnuranMultiContDist(void *p) {
      return  p ? new(p) ::TUnuranMultiContDist : new ::TUnuranMultiContDist;
   }
   static void *newArray_TUnuranMultiContDist(Long_t nElements, void *p) {
      return p ? new(p) ::TUnuranMultiContDist[nElements] : new ::TUnuranMultiContDist[nElements];
   }
   // Wrapper around operator delete
   static void delete_TUnuranMultiContDist(void *p) {
      delete (static_cast<::TUnuranMultiContDist*>(p));
   }
   static void deleteArray_TUnuranMultiContDist(void *p) {
      delete [] (static_cast<::TUnuranMultiContDist*>(p));
   }
   static void destruct_TUnuranMultiContDist(void *p) {
      typedef ::TUnuranMultiContDist current_t;
      (static_cast<current_t*>(p))->~current_t();
   }
} // end of namespace ROOT for class ::TUnuranMultiContDist

//______________________________________________________________________________
void TUnuranSampler::Streamer(TBuffer &R__b)
{
   // Stream an object of class TUnuranSampler.

   if (R__b.IsReading()) {
      R__b.ReadClassBuffer(TUnuranSampler::Class(),this);
   } else {
      R__b.WriteClassBuffer(TUnuranSampler::Class(),this);
   }
}

namespace ROOT {
   // Wrappers around operator new
   static void *new_TUnuranSampler(void *p) {
      return  p ? new(p) ::TUnuranSampler : new ::TUnuranSampler;
   }
   static void *newArray_TUnuranSampler(Long_t nElements, void *p) {
      return p ? new(p) ::TUnuranSampler[nElements] : new ::TUnuranSampler[nElements];
   }
   // Wrapper around operator delete
   static void delete_TUnuranSampler(void *p) {
      delete (static_cast<::TUnuranSampler*>(p));
   }
   static void deleteArray_TUnuranSampler(void *p) {
      delete [] (static_cast<::TUnuranSampler*>(p));
   }
   static void destruct_TUnuranSampler(void *p) {
      typedef ::TUnuranSampler current_t;
      (static_cast<current_t*>(p))->~current_t();
   }
} // end of namespace ROOT for class ::TUnuranSampler

namespace ROOT {
   static TClass *vectorlEdoublegR_Dictionary();
   static void vectorlEdoublegR_TClassManip(TClass*);
   static void *new_vectorlEdoublegR(void *p = nullptr);
   static void *newArray_vectorlEdoublegR(Long_t size, void *p);
   static void delete_vectorlEdoublegR(void *p);
   static void deleteArray_vectorlEdoublegR(void *p);
   static void destruct_vectorlEdoublegR(void *p);

   // Function generating the singleton type initializer
   static TGenericClassInfo *GenerateInitInstanceLocal(const vector<double>*)
   {
      vector<double> *ptr = nullptr;
      static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(vector<double>));
      static ::ROOT::TGenericClassInfo 
         instance("vector<double>", -2, "vector", 458,
                  typeid(vector<double>), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                  &vectorlEdoublegR_Dictionary, isa_proxy, 0,
                  sizeof(vector<double>) );
      instance.SetNew(&new_vectorlEdoublegR);
      instance.SetNewArray(&newArray_vectorlEdoublegR);
      instance.SetDelete(&delete_vectorlEdoublegR);
      instance.SetDeleteArray(&deleteArray_vectorlEdoublegR);
      instance.SetDestructor(&destruct_vectorlEdoublegR);
      instance.AdoptCollectionProxyInfo(TCollectionProxyInfo::Generate(TCollectionProxyInfo::Pushback< vector<double> >()));

      instance.AdoptAlternate(::ROOT::AddClassAlternate("vector<double>","std::vector<double, std::allocator<double> >"));
      return &instance;
   }
   // Static variable to force the class initialization
   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const vector<double>*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));

   // Dictionary for non-ClassDef classes
   static TClass *vectorlEdoublegR_Dictionary() {
      TClass* theClass =::ROOT::GenerateInitInstanceLocal(static_cast<const vector<double>*>(nullptr))->GetClass();
      vectorlEdoublegR_TClassManip(theClass);
   return theClass;
   }

   static void vectorlEdoublegR_TClassManip(TClass* ){
   }

} // end of namespace ROOT

namespace ROOT {
   // Wrappers around operator new
   static void *new_vectorlEdoublegR(void *p) {
      return  p ? ::new(static_cast<::ROOT::Internal::TOperatorNewHelper*>(p)) vector<double> : new vector<double>;
   }
   static void *newArray_vectorlEdoublegR(Long_t nElements, void *p) {
      return p ? ::new(static_cast<::ROOT::Internal::TOperatorNewHelper*>(p)) vector<double>[nElements] : new vector<double>[nElements];
   }
   // Wrapper around operator delete
   static void delete_vectorlEdoublegR(void *p) {
      delete (static_cast<vector<double>*>(p));
   }
   static void deleteArray_vectorlEdoublegR(void *p) {
      delete [] (static_cast<vector<double>*>(p));
   }
   static void destruct_vectorlEdoublegR(void *p) {
      typedef vector<double> current_t;
      (static_cast<current_t*>(p))->~current_t();
   }
} // end of namespace ROOT for class vector<double>

namespace ROOT {
   // Registration Schema evolution read functions
   int RecordReadRules_libUnuran() {
      return 0;
   }
   static int _R__UNIQUE_DICT_(ReadRules_libUnuran) = RecordReadRules_libUnuran();R__UseDummy(_R__UNIQUE_DICT_(ReadRules_libUnuran));
} // namespace ROOT
namespace {
  void TriggerDictionaryInitialization_libUnuran_Impl() {
    static const char* headers[] = {
"TUnuran.h",
"TUnuranBaseDist.h",
"TUnuranContDist.h",
"TUnuranDiscrDist.h",
"TUnuranEmpDist.h",
"TUnuranMultiContDist.h",
"TUnuranSampler.h",
nullptr
    };
    static const char* includePaths[] = {
"/build/root/src/build-cuda/include",
"/usr/include",
"/build/root/src/build-cuda/include/",
nullptr
    };
    static const char* fwdDeclCode = R"DICTFWDDCLS(
#line 1 "libUnuran dictionary forward declarations' payload"

#pragma diagnostic push
#pragma clang diagnostic ignored "-Wkeyword-compat"
#pragma clang diagnostic ignored "-Wignored-attributes"
#pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
extern int __Cling_AutoLoading_Map;
class  __attribute__((annotate("$clingAutoload$TUnuranBaseDist.h")))  __attribute__((annotate("$clingAutoload$TUnuran.h")))  TUnuranBaseDist;
class  __attribute__((annotate("$clingAutoload$TUnuran.h")))  TUnuran;
class  __attribute__((annotate("$clingAutoload$TUnuranContDist.h")))  TUnuranContDist;
class  __attribute__((annotate("$clingAutoload$TUnuranDiscrDist.h")))  TUnuranDiscrDist;
class  __attribute__((annotate("$clingAutoload$TUnuranEmpDist.h")))  TUnuranEmpDist;
class  __attribute__((annotate("$clingAutoload$TUnuranMultiContDist.h")))  TUnuranMultiContDist;
class  __attribute__((annotate("$clingAutoload$TUnuranSampler.h")))  TUnuranSampler;
#pragma diagnostic pop
)DICTFWDDCLS";
    static const char* payloadCode = R"DICTPAYLOAD(
#line 1 "libUnuran dictionary payload"

#ifndef ROOT_SUPPORT_CLAD
  #define ROOT_SUPPORT_CLAD 1
#endif
#ifndef R__DUMMY_CXX_STANDARD_17
  #define R__DUMMY_CXX_STANDARD_17 1
#endif

#define _BACKWARD_BACKWARD_WARNING_H
// Inline headers
#include "TUnuran.h"
#include "TUnuranBaseDist.h"
#include "TUnuranContDist.h"
#include "TUnuranDiscrDist.h"
#include "TUnuranEmpDist.h"
#include "TUnuranMultiContDist.h"
#include "TUnuranSampler.h"

#undef  _BACKWARD_BACKWARD_WARNING_H
)DICTPAYLOAD";
    static const char* classesHeaders[] = {
"TUnuran", payloadCode, "@",
"TUnuranBaseDist", payloadCode, "@",
"TUnuranContDist", payloadCode, "@",
"TUnuranDiscrDist", payloadCode, "@",
"TUnuranEmpDist", payloadCode, "@",
"TUnuranMultiContDist", payloadCode, "@",
"TUnuranSampler", payloadCode, "@",
nullptr
};
    static bool isInitialized = false;
    if (!isInitialized) {
      TROOT::RegisterModule("libUnuran",
        headers, includePaths, payloadCode, fwdDeclCode,
        TriggerDictionaryInitialization_libUnuran_Impl, {}, classesHeaders, /*hasCxxModule*/false);
      isInitialized = true;
    }
  }
  static struct DictInit {
    DictInit() {
      TriggerDictionaryInitialization_libUnuran_Impl();
    }
  } __TheDictionaryInitializer;
}
void TriggerDictionaryInitialization_libUnuran() {
  TriggerDictionaryInitialization_libUnuran_Impl();
}
